#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-A2DwoHIrJ1HFVvUU196ZF1
key:                  ghcide-2.3.0.0-A2DwoHIrJ1HFVvUU196ZF1
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  94be6151568ef45ca8b1418185f60298
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-A2DwoHIrJ1HFVvUU196ZF1
depends:
    Diff-1.0-4F96IMAnGh7AOlcbsBnTkK Glob-0.10.2-7WtetwblUiV5LQvRccYMPi
    aeson-2.2.2.0-FQ3HoQr5jsSKbzQRkDKuNE array-0.5.6.0
    async-2.2.6-GtVZdAjyiB3HTVxVSGqO8l base-4.18.2.1
    base16-bytestring-1.0.2.0-CpWrlklfSq1B5ZY6mOVw28 binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-75BwTjwSfoc3sgy0QhC9q4
    co-log-core-0.3.2.6-ADZ57n3V4L210vuvxEJhe3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-2RavnR12gTZDIeIUyAzZB
    data-default-0.7.1.3-77Hl1aAsEdQ8CHtlu2eaQ1 deepseq-1.4.8.1
    dependent-map-0.4.0.1-6SxCct5tNpJCyJErA1iluz
    dependent-sum-0.7.2.0-AmKFOsg7yDyEzAGRryxn4U directory-1.3.8.5
    dlist-1.0-E4nzd0wXVL0KrvsIzpR7uT
    enummapset-0.7.3.0-5SWMyapebVNEoUyfwG0Vg1 exceptions-0.10.7
    extra-1.7.16-HALhSAGzjFKFE31SaPlKoT filepath-1.4.300.1
    fingertree-0.1.6.3-5r56lEPailbT3dqi1nhwz
    focus-1.0.3.2-ITE0NSmSMi1H6bdEhHNnJi ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-Gz5dwSl2FXMCbj5sVVYkEB
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-AcaIbxAjfGCCuYRAh59JiR
    hashable-1.4.7.0-7UbNEk44IiMJoszryX1sDf
    hie-bios-0.12.0-GzJvVmChld93BSGWIj283S
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-GYJjIANtFrYHagDjuIdgy5
    hls-graph-2.3.0.0-BcLbHT7Qb3SJxzHPpxomLi
    hls-plugin-api-2.3.0.0-aP9mSmyFvB4NwhVA5HEXM
    implicit-hie-0.1.4.0-7to9cmt3ygVeqWuGUuOvu
    implicit-hie-cradle-0.5.0.1-7H6VyqGjDkJF0ALLn5fsAA
    lens-5.3.5-EVMkKptvsirJjkDr2DJD9L
    list-t-1.0.5.7-KluQLqokzF7A8hXMuDB1Ws
    lsp-2.2.0.0-KmFQktxGg6WDgdsr5E1TwJ
    lsp-types-2.0.2.0-JNgFQL6lhYK8UXyGiEvNcm mtl-2.3.1
    opentelemetry-0.8.0-ClSBFSWZhUSD2OIVRyKpDK
    optparse-applicative-0.18.1.0-3se4EOVlv606hLWBZRUZg0
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-4whBtEvUR8p9qbdUdtF2iM
    prettyprinter-ansi-terminal-1.1.4-865MUJXhvCzBGwYK8eHW56
    random-1.2.1.3-Ed9sqfiGJWrIk2dDIiP5zT
    regex-tdfa-1.3.2.5-3SUtr6zl8m4ZpuEbYfBOR
    row-types-1.0.1.2-6vlC6xflYO63p5GRfSfBk5
    safe-exceptions-0.1.7.4-Le9ipPm9fc4JGv3gMdPnKW
    sorted-list-0.2.3.1-8YPXDaVmDJPAPWWxVGLHIs
    sqlite-simple-0.4.19.0-5DgrM6Zk5ByGGvB9WXCQPS stm-2.5.1.0
    stm-containers-1.2.1.1-2zGC80De2jr9w8qQeKwfBH
    syb-0.7.3-6KcX3BjpG2VC96bdiog9fw text-2.0.2
    text-rope-0.3-Tf5CacsXHRCZMrMohwXDd time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-4NwnNs4RtDwK8DYnc6XyDt
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-DZIhPqSL0N2YNV8fYQEJ8
    vector-0.13.2.0-746bkLFippyHVcwUkeKsy

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

